.. _mopidy-js:

****************************
Mopidy.js JavaScript library
****************************

We've made a JavaScript library, Mopidy.js, which wraps the
:ref:`websocket-api` and gets you quickly started with working on your client
instead of figuring out how to communicate with Mopidy. This library is used
as the foundation of most :ref:`Mopidy web clients <ext-web>`.

See the `Mopidy.js project <https://github.com/mopidy/mopidy.js>`_ for
detailed usage documentation and demo applications built using Mopidy.js.
